This crate contains kube-rs compatible bindings for Kubernetes custom resources for the gitops.hybrid-cloud-patterns.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
gitops.hybrid-cloud-patterns.io/v1alpha1
Pattern